==> jc-1.4.0.tar.gz: javax/crypto/NullCipher.h <==
// public class javax.crypto.NullCipher

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4bdfff9ea145d6ce javax_crypto_Cipher
// @dep_class b2745a2f83ab7f25 javax_crypto_NullCipher

// header file dependencies
// @dep_header javax_crypto_Cipher

#include "javax/crypto/Cipher.h"

#ifndef _JC_javax_crypto_NullCipher_H_
#define _JC_javax_crypto_NullCipher_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_NullCipher$sub_refs	_jc_javax_crypto_NullCipher$sub_refs;
typedef struct _jc_javax_crypto_NullCipher$sub_nonrefs	_jc_javax_crypto_NullCipher$sub_nonrefs;
typedef struct _jc_javax_crypto_NullCipher$refs	_jc_javax_crypto_NullCipher$refs;
typedef struct _jc_javax_crypto_NullCipher$nonrefs	_jc_javax_crypto_NullCipher$nonrefs;
typedef struct _jc_javax_crypto_NullCipher$object	_jc_javax_crypto_NullCipher$object;

typedef const struct _jc_javax_crypto_NullCipher$vmethods	_jc_javax_crypto_NullCipher$vmethods;
typedef const struct _jc_javax_crypto_NullCipher$vtable	_jc_javax_crypto_NullCipher$vtable;
typedef const struct _jc_javax_crypto_NullCipher$vtype	_jc_javax_crypto_NullCipher$vtype;

// Constructors
extern void _jc_javax_crypto_NullCipher$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_NullCipher$object *);

// Virtual methods structure
struct _jc_javax_crypto_NullCipher$vmethods {
};

// Vtable
struct _jc_javax_crypto_NullCipher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_Cipher$vmethods	javax_crypto_Cipher;
	_jc_javax_crypto_NullCipher$vmethods	javax_crypto_NullCipher;
};

// Vtype
struct _jc_javax_crypto_NullCipher$vtype {
	_jc_type			type;
	_jc_javax_crypto_NullCipher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_NullCipher$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_NullCipher$refs {
    _jc_javax_crypto_NullCipher$sub_refs	javax_crypto_NullCipher;
    _jc_javax_crypto_Cipher$sub_refs	javax_crypto_Cipher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_NullCipher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_NullCipher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_Cipher$sub_nonrefs	javax_crypto_Cipher;
    _jc_javax_crypto_NullCipher$sub_nonrefs	javax_crypto_NullCipher;
};

// Object instance structure
struct _jc_javax_crypto_NullCipher$object {
	_jc_javax_crypto_NullCipher$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_NullCipher$vtype	*vtype;
	_jc_javax_crypto_NullCipher$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_NullCipher$vtype _jc_javax_crypto_NullCipher$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_NullCipher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_NullCipher$class_object;

#endif	/* _JC_javax_crypto_NullCipher_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/NullCipher.h <==
// public class javax.crypto.NullCipher

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4bdfff9ea145d6ce javax_crypto_Cipher
// @dep_class b2745a2f83ab7f25 javax_crypto_NullCipher

// header file dependencies
// @dep_header javax_crypto_Cipher

#include "javax/crypto/Cipher.h"

#ifndef _JC_javax_crypto_NullCipher_H_
#define _JC_javax_crypto_NullCipher_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_NullCipher$sub_refs	_jc_javax_crypto_NullCipher$sub_refs;
typedef struct _jc_javax_crypto_NullCipher$sub_nonrefs	_jc_javax_crypto_NullCipher$sub_nonrefs;
typedef struct _jc_javax_crypto_NullCipher$refs	_jc_javax_crypto_NullCipher$refs;
typedef struct _jc_javax_crypto_NullCipher$nonrefs	_jc_javax_crypto_NullCipher$nonrefs;
typedef struct _jc_javax_crypto_NullCipher$object	_jc_javax_crypto_NullCipher$object;

typedef const struct _jc_javax_crypto_NullCipher$vmethods	_jc_javax_crypto_NullCipher$vmethods;
typedef const struct _jc_javax_crypto_NullCipher$vtable	_jc_javax_crypto_NullCipher$vtable;
typedef const struct _jc_javax_crypto_NullCipher$vtype	_jc_javax_crypto_NullCipher$vtype;

// Constructors
extern void _jc_javax_crypto_NullCipher$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_NullCipher$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_crypto_NullCipher$vmethods {
};

// Vtable
struct _jc_javax_crypto_NullCipher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_Cipher$vmethods	javax_crypto_Cipher;
	_jc_javax_crypto_NullCipher$vmethods	javax_crypto_NullCipher;
};

// Vtype
struct _jc_javax_crypto_NullCipher$vtype {
	_jc_type			type;
	_jc_javax_crypto_NullCipher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_NullCipher$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_NullCipher$refs {
    _jc_javax_crypto_NullCipher$sub_refs	javax_crypto_NullCipher;
    _jc_javax_crypto_Cipher$sub_refs	javax_crypto_Cipher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_NullCipher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_NullCipher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_Cipher$sub_nonrefs	javax_crypto_Cipher;
    _jc_javax_crypto_NullCipher$sub_nonrefs	javax_crypto_NullCipher;
};

// Object instance structure
struct _jc_javax_crypto_NullCipher$object {
	_jc_javax_crypto_NullCipher$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_NullCipher$vtype	*vtype;
	_jc_javax_crypto_NullCipher$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_NullCipher$vtype _jc_javax_crypto_NullCipher$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_NullCipher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_NullCipher$class_object;

#endif	/* _JC_javax_crypto_NullCipher_H_ */
